@@ -23,6 +23,7 @@
 #include <libglom/connectionpool.h>
 #include <libglom/document/document.h>
 #include <libglom/utils.h>
+#include <libglom/db_utils.h>
 //#include <libgdamm/connectionevent.h>
 
 #include <libglom/connectionpool_backends/postgres_central.h>
@@ -268,6 +269,8 @@ static bool on_connection_pool_cache_timeout()
 
 sharedptr<SharedConnection> ConnectionPool::connect()
 {
+  //std::cout << G_STRFUNC << ": debug" << std::endl;
+
   //Don't try to connect if we don't have a backend to connect to.
   g_return_val_if_fail(m_backend.get(), sharedptr<SharedConnection>(0));
 
@@ -340,11 +343,16 @@ sharedptr<SharedConnection> ConnectionPool::connect()
         {
           //update_meta_store_table_names() has been known to throw an exception.
           //Glom is mostly unusable when it fails, but that's still better than a crash.
-          m_refGdaConnection->update_meta_store_table_names(m_backend->get_public_schema_name());
+          //std::cout << G_STRFUNC << ": Before update_meta_store_table_name()" << std::endl;
+          const bool test = m_refGdaConnection->update_meta_store_table_names(m_backend->get_public_schema_name());
+          if(!test && !m_fake_connection)
+          {
+            std::cerr << G_STRFUNC << ": update_meta_store_table_names() failed without an exception." << std::endl;
+          }
         }
         catch(const Glib::Error& ex)
         {
-          //If the conneciton was not opened, because it is a fake connection,
+          //If the connection was not opened, because it is a fake connection,
           //then we should not be surprised that this fails,
           //and a warning will only be useful later when get_meta_store_data() fails when used in get_table_names_from_database().
           if(!m_fake_connection)
@@ -376,7 +384,7 @@ sharedptr<SharedConnection> ConnectionPool::connect()
   }
   else
   {
-    //g_warning("ConnectionPool::connect(): not ready to connect.");
+    //std::cerr << G_STRFUNC << ": not ready to connect." << std::endl;
   }
 
   return sharedptr<SharedConnection>(0);
@@ -496,6 +504,10 @@ Glib::ustring ConnectionPool::get_database() const
 
 const FieldTypes* ConnectionPool::get_field_types() const
 {
+  //TODO: Investigate this:
+  //if(!m_pFieldTypes)
+  //  std::cerr << G_STRFUNC << ": m_pFieldTypes is null but this should never happen." << std::endl;
+
   return m_pFieldTypes;
 }
 
@@ -507,6 +519,7 @@ Gnome::Gda::SqlOperatorType ConnectionPool::get_string_find_operator() const
 
 void ConnectionPool::invalidate_connection()
 {
+  //std::cerr << G_STRFUNC << ": debug" << std::endl;
   connection_cached.clear();
   connection_cached_timeout_connection.disconnect();
   connection_cached_finished_connection.disconnect();
@@ -516,6 +529,9 @@ void ConnectionPool::invalidate_connection()
     
   m_refGdaConnection.reset();
   m_sharedconnection_refcount = 0;
+
+  delete m_pFieldTypes;
+  m_pFieldTypes = 0;
 }
 
 void ConnectionPool::on_sharedconnection_finished()
@@ -530,7 +546,7 @@ void ConnectionPool::on_sharedconnection_finished()
   {
     //There should be no copies of the m_refConnection, so the Gnome::Gda::Connection destructor should
     //run when we clear this last RefPtr of it, but we will explicitly close it just in case.
-    //g_warning("ConnectionPool::on_sharedconnection_finished(): closing GdaConnection");
+    //std::cerr << G_STRFUNC << ": closing GdaConnection" << std::endl;
     m_refGdaConnection->close();
 
     m_refGdaConnection.reset();
@@ -747,7 +763,31 @@ bool ConnectionPool::change_columns(const Glib::ustring& table_name, const type_
 
   const bool result = m_backend->change_columns(m_refGdaConnection, table_name, old_fields, new_fields);
   m_refGdaConnection->update_meta_store_table(table_name, m_backend->get_public_schema_name());
+  if(!result)
+    return false;
 
+  //Add or remove any auto-increment rows:
+  //The new auto-increment row would actually be added automatically,
+  //but this makes it available even before a record has been added. 
+  type_vec_const_fields::const_iterator iter_old = old_fields.begin();
+  type_vec_const_fields::const_iterator iter_new = new_fields.begin();
+  while( (iter_old != old_fields.end()) && (iter_new != new_fields.end()) )
+  {
+    const sharedptr<const Field> field_old = *iter_old;
+    const sharedptr<const Field> field_new = *iter_new;
+    if(field_old && field_new
+      && field_old->get_auto_increment() != field_new->get_auto_increment())
+    {
+      if(field_new->get_auto_increment())
+        DbUtils::auto_increment_insert_first_if_necessary(table_name, field_new->get_name());
+      else
+        DbUtils::remove_auto_increment(table_name, field_new->get_name());
+    }
+
+    ++iter_old;
+    ++iter_new;
+  }
+ 
   return result;
 }
 
