@@ -31,7 +31,8 @@ namespace Glom
 class LayoutItem_Field;
 
 /** The child items are fields to be shown for each record in the group.
- * field_group_by is the field by which the records are grouped.
+ * The records are grouped by a specified field and there may be.
+ * secondary fields that are also shown for each group.
  */
 class LayoutItem_GroupBy : public LayoutGroup
 {
@@ -67,13 +68,18 @@ public:
   virtual Glib::ustring get_part_type_name() const;
   virtual Glib::ustring get_report_part_id() const;
 
-  //TODO: Add get/set methods for this:
-  sharedptr<LayoutGroup> m_group_secondary_fields; //For instance, show a contact name as well as the contact ID that we group by.
-
-  type_list_sort_fields m_fields_sort_by;
+  sharedptr<LayoutGroup> get_secondary_fields();
+  sharedptr<const LayoutGroup> get_secondary_fields() const;
 
+  //TODO: Is this used by anything?
+  type_list_sort_fields get_sort_by() const;
+  void set_sort_by(const type_list_sort_fields& sort_by);
+  
 private:
+
   sharedptr<LayoutItem_Field> m_field_group_by;
+  sharedptr<LayoutGroup> m_group_secondary_fields; //For instance, show a contact name as well as the contact ID that we group by.
+  type_list_sort_fields m_fields_sort_by;
 };
 
 } //namespace Glom
