@@ -1232,7 +1232,7 @@ DbAddDel::InnerIgnore::~InnerIgnore()
     m_pOuter->set_ignore_treeview_signals(m_bIgnoreTreeViewSignals);
   }
 
-  m_pOuter = false;
+  m_pOuter = 0;
 }
 
 Gnome::Gda::Value DbAddDel::treeview_get_key(const Gtk::TreeModel::iterator& row) const
