@@ -18,9 +18,21 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <gtkmm.h>
 #include <glom/utility_widgets/eggspreadtable/eggspreadtablednd.h>
 #include <glom/utility_widgets/eggspreadtablemm/eggspreadtabledndmm.h>
+#include <gtkmm/window.h>
+#include <gtkmm/entry.h>
+#include <gtkmm/label.h>
+#include <gtkmm/box.h>
+#include <gtkmm/button.h>
+#include <gtkmm/spinbutton.h>
+#include <gtkmm/expander.h>
+#include <gtkmm/togglebutton.h>
+#include <gtkmm/eventbox.h>
+#include <gtkmm/frame.h>
+#include <gtkmm/comboboxtext.h>
+#include <gtkmm/scrolledwindow.h>
+#include <gtkmm/application.h>
 
 static const guint INITIAL_HSPACING = 2;
 static const guint INITIAL_VSPACING = 2;
@@ -37,7 +49,7 @@ static bool parent_accepts_drops = true;
 
 
 static void
-populate_spread_table_wrappy(Egg::SpreadTable* spread_table)
+populate_spread_table_wrappy(Egg::SpreadTableDnd* spread_table)
 {
   const gchar *strings[] = {
     "These are", "some wrappy label", "texts", "of various", "lengths.",
@@ -55,7 +67,7 @@ populate_spread_table_wrappy(Egg::SpreadTable* spread_table)
     iter != children.end(); ++iter)
   {
     Gtk::Widget *child = *iter;
-    paper->remove(*child);
+    paper->remove_child(*child);
     delete child;
   }
 
@@ -117,21 +129,19 @@ on_combo_halign_changed()
 }
 
 static bool
-on_spreadtable_parent_drop_possible(Gtk::Widget* /* child */)
+on_spreadtable_parent_drop_possible(Gtk::Widget* /* child */, bool& drop_possible)
 {
-  if(parent_accepts_drops)
-    return true;
+  drop_possible = parent_accepts_drops;
 
-  return false;
+  return TRUE; //Handled, instead of using the default behaviour.
 }
 
 static bool
-on_inner_spreadtable_drop_possible(Gtk::Widget* /* child */)
+on_inner_spreadtable_drop_possible(Gtk::Widget* /* child */, bool& drop_possible)
 {
-  if(child_accepts_drops)
-    return true;
+  drop_possible = child_accepts_drops;
 
-  return false;
+  return TRUE; //Handled, instead of using the default behaviour.
 }
 
 static void
@@ -144,9 +154,9 @@ static Gtk::Window *
 create_window()
 {
   Gtk::Window* window = new Gtk::Window();
-  Gtk::HBox* hbox = Gtk::manage(new Gtk::HBox(false, 2));
+  Gtk::Box* hbox = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL, 2));
   hbox->show();
-  Gtk::VBox* vbox = Gtk::manage(new Gtk::VBox(false, 6));
+  Gtk::Box* vbox = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_VERTICAL, 6));
   vbox->show();
 
   window->set_border_width (8);
@@ -178,7 +188,7 @@ create_window()
   /* Add SpreadTable test control frame */
   Gtk::Expander* expander = Gtk::manage(new Gtk::Expander("SpreadTable controls"));
   expander->set_expanded();
-  Gtk::VBox* paper_cntl = Gtk::manage(new Gtk::VBox(false, 2));
+  Gtk::Box* paper_cntl = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_VERTICAL, 2));
   paper_cntl->show();;
   expander->show();
   expander->add(*paper_cntl);
@@ -198,7 +208,7 @@ create_window()
     sigc::ptr_fun(&on_combo_orientation_changed));
 
   /* Add horizontal/vertical spacing controls */
-  hbox = Gtk::manage(new Gtk::HBox(false, 2));
+  hbox = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL, 2));
   hbox->show();
 
   Gtk::Widget* label = Gtk::manage(new Gtk::Label("H Spacing"));
@@ -223,7 +233,7 @@ create_window()
 
   paper_cntl->pack_start(*hbox, false, false, 0);
 
-  hbox = Gtk::manage(new Gtk::HBox(false, 2));
+  hbox = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL, 2));
   hbox->show();
 
   label =  Gtk::manage(new Gtk::Label("V Spacing"));
@@ -268,7 +278,7 @@ create_window()
       togglebutton, child_accepts_drops));
 
   /* Add lines controls */
-  hbox = Gtk::manage(new Gtk::HBox(false, 2));
+  hbox = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL, 2));
   hbox->show();
 
   label = Gtk::manage(new Gtk::Label("Lines"));
@@ -293,7 +303,7 @@ create_window()
   /* Add test items control frame */
   expander = Gtk::manage(new Gtk::Expander("Test item controls"));
   expander->set_expanded();
-  Gtk::VBox* items_cntl = Gtk::manage(new Gtk::VBox(false, 2));
+  Gtk::Box* items_cntl = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_VERTICAL, 2));
   items_cntl->show();
   expander->show();
   expander->add(*items_cntl);
@@ -348,10 +358,9 @@ create_window()
 int
 main(int argc, char *argv[])
 {
-  Gtk::Main kit(argc, argv);
+  Glib::RefPtr<Gtk::Application> app = 
+    Gtk::Application::create(argc, argv, "org.glom.test_spreadtablednd");
 
   Gtk::Window* window = create_window();
-  Gtk::Main::run(*window);
-
-  return 0;
+  return app->run(*window);
 }
