@@ -21,13 +21,14 @@
 #ifndef GLOM_UTILITY_WIDGETS_PLACEHOLDER_H
 #define GLOM_UTILITY_WIDGETS_PLACEHOLDER_H
 
-#include <gtkmm.h>
+#include <gtkmm/box.h>
 #include <gtkmm/builder.h>
 
 namespace Glom
 {
 
-//TODO: Remove this, using the vbox directly?
+/** This is just an easy way to use a Gtk::Box as a single-item container.
+ */
 class PlaceHolder : public Gtk::Box
 {
 public:
